@@ -1,3 +1,5 @@
+require 'active_support/inflector' # for the sake of camelcasing keys
+
 module Rabl
   class Builder
     include Helpers
@@ -135,10 +137,13 @@ module Rabl
       # attribute :foo, :as => "bar"
       # attribute :foo, :as => "bar", :if => lambda { |m| m.foo }
       def attribute(name, options = {})
-        return unless @_object && attribute_present?(name) && resolve_condition(options)
+        return unless
+          @_object &&
+          attribute_present?(name) &&
+          resolve_condition(options)
 
         attribute = data_object_attribute(name)
-        name = (options[:as] || name).to_sym
+        name = create_key(options[:as] || name)
         @_result[name] = attribute
       end
       alias_method :attributes, :attribute
@@ -151,7 +156,7 @@ module Rabl
 
         result = block.call(@_object)
         if name.present?
-          @_result[name.to_sym] = result
+          @_result[create_key(name)] = result
         elsif result.is_a?(Hash) # merge hash into root hash
           @_result.merge!(result)
         end
@@ -174,7 +179,7 @@ module Rabl
 
         object = { object => name } if data.is_a?(Hash) && object # child :users => :people
 
-        engines << { name.to_sym => object_to_engine(object, engine_options, &block) }
+        engines << { create_key(name) => object_to_engine(object, engine_options, &block) }
       end
 
       # Glues data from a child node to the json_output
@@ -198,10 +203,11 @@ module Rabl
 
       # Evaluate conditions given a symbol/proc/lambda/variable to evaluate
       def call_condition_proc(condition, object)
-        # This will evaluate lambda, proc & symbol and call it with 1 argument
-        return condition.to_proc.call(object) if condition.is_a?(Proc) || condition.is_a?(Symbol)
-        # Else we send directly the object
-        condition
+        case condition
+        when Proc   then condition.call(object)
+        when Symbol then condition.to_proc.call(object)
+        else             condition
+        end
       end
 
       # resolve_condition(:if => true) => true
@@ -211,8 +217,10 @@ module Rabl
       # resolve_condition(:unless => lambda { |m| false }, :if => proc { true}) => true
       def resolve_condition(options)
         result = true
-        result &&= call_condition_proc(options[:if], @_object) if options.key?(:if)
-        result &&= !call_condition_proc(options[:unless], @_object) if options.key?(:unless)
+        result &&=  call_condition_proc(options[:if], @_object)     if
+          options.key?(:if)
+        result &&= !call_condition_proc(options[:unless], @_object) if
+          options.key?(:unless)
         result
       end
 
@@ -220,13 +228,9 @@ module Rabl
       # Checks if an attribute is present. If not, check if the configuration specifies that this is an error
       # attribute_present?(created_at) => true
       def attribute_present?(name)
-        if @_object.respond_to?(name)
-          true
-        elsif Rabl.configuration.raise_on_missing_attribute
-          raise "Failed to render missing attribute #{name}"
-        else
-          false
-        end
+        @_object.respond_to?(name) ||
+          (Rabl.configuration.raise_on_missing_attribute &&
+           raise("Failed to render missing attribute #{name}"))
       end
 
       # Returns a guess at the format in this context_scope
@@ -248,5 +252,13 @@ module Rabl
           yield
         end
       end
+
+      def create_key(name)
+        if Rabl.configuration.camelize_keys
+          name.to_s.camelize(Rabl.configuration.camelize_keys == :upper ? :upper : :lower).to_sym
+        else
+          name.to_sym
+        end
+      end
   end
 end
