@@ -6,6 +6,7 @@ module Rabl
 
     # List of supported rendering formats
     FORMATS = [:json, :xml, :plist, :bson, :msgpack]
+    SAFE_FORMATS = FORMATS + [:mpac, :dumpable, :hash]
 
     # Constructs a new ejs engine based on given vars, handler and declarations
     # Rabl::Engine.new("...source...", { :format => "xml", :root => true, :view_path => "/path/to/views" })
@@ -27,6 +28,8 @@ module Rabl
     # Renders the representation based on source, object, context_scope and locals
     # Rabl::Engine.new("...source...", { :format => "xml" }).apply(context_scope, { :foo => "bar", :object => @user })
     def apply(context_scope, locals, &block)
+      locals = locals.dup unless locals.nil?
+
       set_instance_variables!(context_scope, locals)
 
       reset_settings!
@@ -58,8 +61,10 @@ module Rabl
         if digestor_available? && respond_to?(:lookup_context) && lookup_context
           template = @_options[:template] || @virtual_path
 
-          digest = \
-            if Gem::Version.new(Rails.version) >= Gem::Version.new('4.1')
+          digest =
+            if Rails.version.to_s =~ /^[67]/
+              Digestor.digest(name: template, finder: lookup_context, format: :rabl)
+            elsif Gem::Version.new(Rails.version) >= Gem::Version.new('4.1')
               Digestor.digest(:name => template, :finder => lookup_context)
             else
               Digestor.digest(template, :rabl, lookup_context)
@@ -81,7 +86,7 @@ module Rabl
 
       options[:root_name] = determine_object_root(data, root_name, options[:root])
 
-      result = \
+      result =
         if is_object?(data) || !data # object @user
           Builder.new(data, @_settings, options).to_hash
         elsif is_collection?(data) # collection @users
@@ -165,6 +170,7 @@ module Rabl
       @_root_name_data = @_root_name_data.values.first if @_root_name_data.is_a?(Hash)
 
       # If we turn this around, `@_root_name_date ==` may trigger data to be loaded unnecessarily.
+      # TODO: is nil a different semantic? otherwise don't use `false ==`, use !
       if false == @_root_name_data
         @_object_root_name = false
         @_collection_name = false
@@ -387,7 +393,11 @@ module Rabl
       end
 
       def digestor_available?
-        defined?(Rails) && Rails.version =~ /^[45]/
+        defined?(Rails) && Rails.version =~ /^[4567]/
+      end
+
+      def valid_format?(format)
+        SAFE_FORMATS.include?(format.to_sym) && respond_to?("to_#{format}")
       end
 
       def set_instance_variables!(context_scope, locals)
@@ -398,6 +408,9 @@ module Rabl
 
         @_options[:format] ||= request_format
 
+        # Prevent calls to inherited methods `to_yaml`, `to_enum`, etc.
+        @_options[:format] = 'json' unless valid_format?(@_options[:format])
+
         set_locals(@_locals)
       end
 
@@ -407,15 +420,21 @@ module Rabl
       end
 
       def eval_source(locals, &block)
-        # Note: locals and block may be used by the eval'ed source
-
         return unless @_source.present?
 
-        if @_options[:source_location]
-          instance_eval(@_source, @_options[:source_location])
-        else
-          instance_eval(@_source)
+        msg = "cached_source_#{@_source.hash.abs}"
+
+        unless self.respond_to? msg then
+          src = "def #{msg} locals, &block\n#{@_source}\nend"
+
+          if @_options[:source_location]
+            self.class.class_eval(src, @_options[:source_location])
+          else
+            self.class.class_eval(src)
+          end
         end
+
+        send msg, locals, &block
       end
   end
 end
