@@ -23,6 +23,12 @@ context "Rabl::Engine" do
     asserts_topic.assigns :_view_path
   end
 
+  context "#apply" do
+    denies("that it raises exception when given frozen locals").raises(RuntimeError) do
+      Rabl::Engine.new("").apply(Object.new, {}.freeze)
+    end
+  end
+
   context "#request_format" do
     context "is json by default" do
       setup do
@@ -41,6 +47,31 @@ context "Rabl::Engine" do
 
       asserts_topic.includes('<foo>bar</foo>')
     end
+
+    context "don't allow calls to inherited methods; default to JSON" do
+      code = 'node(:foo) { "bar" }'
+      expected_json = '{"foo":"bar"}'
+      setup do
+        template = RablTemplate.new("code", :format => 's') { code }
+        template.render(Object.new)
+      end
+
+      asserts_topic.equivalent_to(expected_json)
+
+      setup do
+        template = RablTemplate.new("code", :format => 'ruby') { code }
+        template.render(Object.new)
+      end
+
+      asserts_topic.equivalent_to(expected_json)
+
+      setup do
+        template = RablTemplate.new("code", :format => 'enum') { code }
+        template.render(Object.new)
+      end
+
+      asserts_topic.equivalent_to(expected_json)
+    end
   end
 
   context "#cache" do
@@ -444,7 +475,7 @@ context "Rabl::Engine" do
 
         any_instance_of(Rabl::Engine) do |b|
           mock(b).fetch_source("foo/bar", :view_path => nil).once
-          mock(b).object_to_engine(@user, :locals => { :foo => "bar" }, :source => nil, :source_location => nil, :template => 'foo/bar').returns(e)
+          mock(b).object_to_engine(@user, { :locals => { :foo => "bar" }, :source => nil, :source_location => nil, :template => 'foo/bar' }).returns(e)
         end
         JSON.parse(template.render(scope))
       end.equals JSON.parse("{ \"foo\" : {\"name\":\"leo\",\"city\":\"LA\",\"age\":12} }")
